@@ -1,12 +1,13 @@
 /**************************************************************************
  *  Kchmviewer for Maemo5 - a CHM file viewer with broad language support *
+ *  Port of KChmViewer ( www.kchmviewer.net ) to mobile platforms         *
  *  Copyright (C) 2009-2010 Max Kiva , max.kiva@gmail.com                 *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
  *  the Free Software Foundation, either version 3 of the License, or     *
  *  (at your option) any later version.                                   *
- *															                                  	      *
+ *                                                                        *
  *  This program is distributed in the hope that it will be useful,       *
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
@@ -35,6 +36,8 @@
  * QWebKitPageBrowser  QTextBrowserPageBrowser
  */
 
+class Chm;
+
 class PageViewWidget : public QTextBrowser
 {
   Q_OBJECT
@@ -47,17 +50,21 @@ class PageViewWidget : public QTextBrowser
     void  openPageNum( size_t page );
     bool  openPage (const QString& url);
 
-
+    const QString& fileName() const { return filename_; }
     const ChmEntryList& getContents() const { return tableOfContents_; }
+    Chm* chm() { return chm_; }
 
     int getScrollBarPos() const { return verticalScrollBar()->sliderPosition(); }
     void setScrollBarPos( int pos ) { verticalScrollBar()->setSliderPosition(pos); } 
 
+    
+
   
     void nextPage();
     void prevPage();
     void zoomIn();
     void zoomOut();
+    void bookmarkCurrentPage();
   
   protected:
     // from QTextBrowser - called internally
@@ -68,7 +75,9 @@ class PageViewWidget : public QTextBrowser
     QString makeURLabsolute ( const QString & url, bool set_as_base );
   private:
 
-    LCHMFile* chm_;
+//    LCHMFile* chm_;
+    Chm*  chm_;
+    QString filename_;
     ChmEntryList tableOfContents_;
     QString baseUrl_;
     size_t page_;
