@@ -15,19 +15,12 @@
  *  You should have received a copy of the GNU General Public License     *
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  **************************************************************************/
-#include <iostream>
 #include <QtGui>
 #include <qpixmap.h>
 #include "mainwindow.h"
 #include "toolbarwidget.h"
+#include "resources.h"
 
-#include "openfile.xpm"
-#include "contents.xpm"
-#include "fullscreen.xpm"
-#include "nextpage.xpm"
-#include "prevpage.xpm"
-#include "zoomin.xpm"
-#include "zoomout.xpm"
 
 
 /***********************************************************
@@ -37,24 +30,42 @@ ToolBarWidget::ToolBarWidget( QWidget* parent )
   : QWidget(parent),
     layout_( new QHBoxLayout(this) )
 {
-  btns_[0] = new QPushButton( QPixmap( openfile_xpm ), 0, this );
-  connect( btns_[0], SIGNAL(clicked()), this , SLOT(clickedOpenFile()) );
-  btns_[1] = new QPushButton( QPixmap( contents_xpm ), 0, this );
-  connect( btns_[1], SIGNAL(clicked()), this , SLOT(clickedContents()) );
-  btns_[2] = new QPushButton( QPixmap( prevpage_xpm ), 0, this );
-  connect( btns_[2], SIGNAL(clicked()), this , SLOT(clickedPrevPage()) );
-  btns_[3] = new QPushButton( QPixmap( nextpage_xpm ), 0, this );
-  connect( btns_[3], SIGNAL(clicked()), this , SLOT(clickedNextPage()) );
-  btns_[4] = new QPushButton( QPixmap( zoomin_xpm ), 0, this );
-  connect( btns_[4], SIGNAL(clicked()), this , SLOT(clickedZoomIn()) );
-  btns_[5] = new QPushButton( QPixmap( zoomout_xpm ), 0, this );
-  connect( btns_[5], SIGNAL(clicked()), this , SLOT(clickedZoomOut()) );
-  btns_[6] = new QPushButton( QPixmap( fullscreen_xpm ), 0, this );
-  connect( btns_[6], SIGNAL(clicked()), this , SLOT(clickedFullScreen()) );
+  btns_[EOpen] = new QPushButton( QPixmap( iconOpen() ), 0, this );
+  connect( btns_[EOpen], SIGNAL(clicked()), this , SLOT(clickedOpenFile()) );
+  
+  btns_[ERecentDocs] = new QPushButton( QPixmap( iconRecentDocs() ), 0, this );
+  connect( btns_[ERecentDocs], SIGNAL(clicked()), this , SLOT(clickedRecentDocs()) );
+  
+  btns_[EContents] = new QPushButton( QPixmap( iconContents() ), 0, this );
+  connect( btns_[EContents], SIGNAL(clicked()), this , SLOT(clickedContents()) );
 
-  for( int i =0 ; i < BUTTON_NUM; ++i )
+
+  btns_[EBookmarks] = new QPushButton( QPixmap( QPixmap(iconBookmarks()) ), 0, this );
+  connect( btns_[EBookmarks], SIGNAL(clicked()), this , SLOT(clickedBookmarks()) );
+
+  btns_[EFind] = new QPushButton( QPixmap( QPixmap(iconSearch()) ), 0, this );
+  connect( btns_[EFind], SIGNAL(clicked()), this , SLOT(clickedFind()) );
+
+
+  btns_[EPrev] = new QPushButton( QPixmap(iconBack()), 0, this );
+  connect( btns_[EPrev], SIGNAL(clicked()), this , SLOT(clickedPrevPage()) );
+  
+  btns_[ENext] = new QPushButton( QPixmap( iconForward() ), 0, this );
+  connect( btns_[ENext], SIGNAL(clicked()), this , SLOT(clickedNextPage()) );
+  
+  btns_[EZoomIn] = new QPushButton( QPixmap(iconZoomIn()), 0, this );
+  connect( btns_[EZoomIn], SIGNAL(clicked()), this , SLOT(clickedZoomIn()) );
+  
+  btns_[EZoomOut] = new QPushButton( QPixmap(iconZoomOut() ), 0, this );
+  connect( btns_[EZoomOut], SIGNAL(clicked()), this , SLOT(clickedZoomOut()) );
+  
+  btns_[EFullScreen] = new QPushButton( QPixmap( iconFullScreen() ), 0, this );
+  connect( btns_[EFullScreen], SIGNAL(clicked()), this , SLOT(clickedFullScreen()) );
+
+  for( int i =0 ; i < ENumButtons; ++i )
   {
-    if(i)
+    btns_[i]->show();
+    if(i > 1)
     {
       btns_[i]->setEnabled(false);
     }
@@ -69,7 +80,7 @@ ToolBarWidget::ToolBarWidget( QWidget* parent )
  */
 ToolBarWidget::~ToolBarWidget()
 {
-  for( int i =0 ; i < BUTTON_NUM; ++i )
+  for( int i =0 ; i < ENumButtons; ++i )
   {
       delete btns_[i];
   }
@@ -79,7 +90,7 @@ ToolBarWidget::~ToolBarWidget()
 void ToolBarWidget::enableButtons( bool enable )
 {
 
-  for( int i =0 ; i < BUTTON_NUM; ++i )
+  for( int i =0 ; i < ENumButtons; ++i )
   {
       btns_[i]->setEnabled(enable);
   }
@@ -105,6 +116,24 @@ void ToolBarWidget::clickedContents()
   wnd->doOpenTableOfContents();
 }
 
+/*****************************************************************************
+ *
+ */
+void ToolBarWidget::clickedRecentDocs()
+{
+  MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
+  wnd->doRecentDocs();
+}
+void ToolBarWidget::clickedFind()
+{
+  MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
+  wnd->doFind();
+}
+void ToolBarWidget::clickedBookmarks()
+{
+  MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
+  wnd->doBookmarks();
+}
 void ToolBarWidget::clickedZoomOut()
 {
   MainWindow* wnd = dynamic_cast<MainWindow*>(parentWidget()); 
